/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is McCoy.
 *
 * Contributor(s):
 *  Dave Townsend <dtownsend@oxymoronical.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

const RANDOMLENGTH = 200;
const Cc = Components.classes;
const Ci = Components.interfaces;

var gRandom = "";

function initRandom()
{
  /* We may have already visited the page before so only disabling advancing
     if we don't have data. */
  if (gRandom.length < RANDOMLENGTH) {
    document.documentElement.canAdvance = false;
  }
}

/**
 * We build up some random data using the keys typed and the time between
 * keystrokes. We take as much data as we can but allow the user to proceed
 * once we have 200 characters (normally 100 keystrokes).
 */
function addToRandom(event)
{
  // Some keystrokes don't have a code, just ignore it if not
  if (event.charCode)
    gRandom += String.fromCharCode(event.charCode);

  // Generally the low byte of the time ought to be fairly random
  gRandom += String.fromCharCode(event.timeStamp % 256);
  var progress = document.getElementById("progress");
  if (gRandom.length >= RANDOMLENGTH) {
    document.documentElement.canAdvance = true;
    progress.value = 100;
  }
  else {
    progress.value = 100 * gRandom.length / RANDOMLENGTH
  }
}

/**
 * Creates the key and returns it through the window arguments
 */
function createKey()
{
  var textbox = document.getElementById("name");
  var name = textbox.value;
  if (name.length > 0) {
    var ks = Cc["@toolkit.mozilla.org/keyservice;1"]
              .getService(Ci.nsIKeyService);
    var key = ks.createKeyPair(Ci.nsIKeyPair.KEYTYPE_RSA, gRandom);
    key.name = name;
    window.arguments[0].key = key;
    return true;
  }
  else {
    alert("You must enter a name for the key.");
    return false;
  }
}
